@@ -105,10 +105,12 @@ record_new <- function(
 }
 
 record_has_error <- function(record) {
-  error <- record$error
+  error <- .subset2(record, "error")
   length(error) > 0L && nzchar(error) && !anyNA(error)
 }
 
+row_has_error <- record_has_error
+
 record_is_target <- function(record) {
   !(record$type %in% c("function", "object"))
 }
@@ -148,12 +150,14 @@ record_row_path <- function(record) {
 record_from_row <- function(row, path_store) {
   record <- do.call(record_init, lapply(row, unlist))
   if (!anyNA(record$format)) {
-    record$path <- store_path_from_record(
+    record$path <- store_path_from_name(
       store = store_mock(
         format = record$format,
         repository = record$repository
       ),
-      record = record,
+      format = record$format,
+      name = record$name,
+      path = record$path,
       path_store = path_store
     )
   }
@@ -183,7 +187,7 @@ record_bootstrap_store <- function(record) {
 
 record_bootstrap_file <- function(record) {
   file <- file_init()
-  file_repopulate(file, record)
+  file_repopulate(file, path = record$path, data = record$data)
   file
 }
 
