@@ -7,6 +7,5 @@ silent_class <- R6::R6Class(
   inherit = reporter_class,
   class = FALSE,
   portable = FALSE,
-  cloneable = FALSE,
-  public = list()
+  cloneable = FALSE
 )
