@@ -70,7 +70,8 @@
 #'   run the script from the current working directory.
 #'   If the argument `NULL`, the setting is not modified.
 #'   Use [tar_config_unset()] to delete a setting.
-#' @param seconds_interval Deprecated on 2023-08-24 (version 1.2.2.9001).
+#' @param seconds_interval Deprecated on 2023-08-24
+#'   (`targets` version 1.2.2.9001).
 #'   Use `seconds_meta_append`, `seconds_meta_upload`,
 #'   and `seconds_reporter` instead.
 #' @param seconds_meta_append Argument of [tar_make()], [tar_make_clustermq()],
@@ -78,11 +79,17 @@
 #'   Positive numeric of length 1 with the minimum
 #'   number of seconds between saves to the local metadata and progress files
 #'   in the data store.
-#'   Higher values generally make the pipeline run faster, but unsaved
+#'   This is an aggressive optimization setting not recommended
+#'   for most users:
+#'   higher values might make the pipeline run faster, but unsaved
 #'   work (in the event of a crash) is not up to date.
+#'
 #'   When the pipeline ends,
 #'   all the metadata and progress data is saved immediately,
 #'   regardless of `seconds_meta_append`.
+#'   When the pipeline is just skipping targets, the actual interval
+#'   between saves is `max(1, seconds_meta_append)` to reduce
+#'   overhead.
 #' @param seconds_meta_upload Argument of [tar_make()], [tar_make_clustermq()],
 #'   and [tar_make_future()].
 #'   Positive numeric of length 1 with the minimum
@@ -97,7 +104,20 @@
 #' @param seconds_reporter Argument of [tar_make()], [tar_make_clustermq()],
 #'   and [tar_make_future()]. Positive numeric of length 1 with the minimum
 #'   number of seconds between times when the reporter prints progress
-#'   messages to the R console.
+#'   messages to the R console (for the aforementioned
+#'   [tar_make()]-like functions only).
+#'   This is an aggressive optimization setting not recommended
+#'   for most users: higher values might make some pipelines run faster,
+#'   but it becomes less clear which targets are actually running
+#'   at any given moment.
+#'   When the pipeline is just skipping targets,
+#'   the actual interval between messages is `max(1, seconds_reporter)`
+#'   to reduce overhead.
+#' @param seconds_reporter_outdated Argument of [tar_outdated()]
+#'   and other related functions that do not run the pipeline.
+#'   Positive numeric of length 1 with the minimum
+#'   number of seconds between times when the reporter prints progress
+#'   messages to the R console for [tar_outdated()].
 #' @param shortcut logical of length 1, default `shortcut` argument
 #'   to [tar_make()] and related functions.
 #'   If the argument `NULL`, the setting is not modified.
@@ -177,6 +197,7 @@ tar_config_set <- function(
   seconds_meta_append = NULL,
   seconds_meta_upload = NULL,
   seconds_reporter = NULL,
+  seconds_reporter_outdated = NULL,
   seconds_interval = NULL,
   store = NULL,
   shortcut = NULL,
@@ -186,7 +207,7 @@ tar_config_set <- function(
   project = Sys.getenv("TAR_PROJECT", "main")
 ) {
   # TODO: remove single-project format, which was deprecated on
-  # 2021-09-03 (version 0.7.0.9001).
+  # 2021-09-03 (targets version 0.7.0.9001).
   tar_assert_chr(config)
   tar_assert_scalar(config)
   tar_assert_chr(project)
@@ -203,6 +224,7 @@ tar_config_set <- function(
   tar_config_assert_seconds_meta_append(seconds_meta_append)
   tar_config_assert_seconds_meta_upload(seconds_meta_upload)
   tar_config_assert_seconds_reporter(seconds_reporter)
+  tar_config_assert_seconds_reporter_outdated(seconds_reporter_outdated)
   tar_config_assert_seconds_interval(seconds_interval)
   tar_config_assert_shortcut(shortcut)
   tar_config_assert_store(store)
@@ -226,8 +248,10 @@ tar_config_set <- function(
     yaml[[project]]$seconds_meta_append
   yaml[[project]]$seconds_meta_upload <- seconds_meta_upload %|||%
     yaml[[project]]$seconds_meta_upload
-  yaml[[project]]$seconds_reporter <- seconds_reporter %|||%
-    yaml[[project]]$seconds_reporter
+  yaml[[project]][["seconds_reporter"]] <- seconds_reporter %|||%
+    yaml[[project]][["seconds_reporter"]]
+  yaml[[project]]$seconds_reporter_outdated <- seconds_reporter_outdated %|||%
+    yaml[[project]]$seconds_reporter_outdated
   yaml[[project]]$seconds_interval <- seconds_interval %|||%
     yaml[[project]]$seconds_interval
   yaml[[project]]$shortcut <- shortcut %|||% yaml[[project]]$shortcut
@@ -272,7 +296,7 @@ tar_config_assert_garbage_collection <- function(garbage_collection) {
   }
   tar_warn_deprecate(
     "The garbage_collection argument of tar_config_set() was deprecated ",
-    "in version 1.8.0.9004 (2024-10-22). The garbage_collection ",
+    "in targets version 1.8.0.9004 (2024-10-22). The garbage_collection ",
     "argument of tar_option_set() is more unified and featureful now. ",
     "Please have a look at its documentation."
   )
@@ -372,6 +396,9 @@ tar_config_assert_seconds_reporter <- function(seconds_reporter) {
   tar_assert_ge(seconds_reporter, 0)
 }
 
+tar_config_assert_seconds_reporter_outdated <-
+  tar_config_assert_seconds_reporter
+
 tar_config_assert_shortcut <- function(shortcut) {
   if (is.null(shortcut)) {
     return()
@@ -418,7 +445,7 @@ tar_reporters_make <- function() {
 }
 
 tar_reporters_outdated <- function() {
-  c("forecast", "silent")
+  c("forecast_interactive", "forecast", "silent")
 }
 
 tar_config_read_yaml <- function(config) {
